StorybookModel class

Marca uma classe de dados (ex.: configuração aninhada no storybook) para gerar merge* via build_runner + pacote storybook_ds_builder.

Requisitos:

  • Construtor não nomeado que recebe todos os campos como parâmetros nomeados.
  • Campos de instância públicos (nomes que não começam com _).

Veja o README do pacote (seção objetos aninhados e code generation).

Constructors

StorybookModel()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited